#include "http_utils.hpp"

HttpResponse http_get(const std::string& url, const std::string& path, bool use_https, double timeout_seconds) {
    HttpResponse result{0, "", false};
    bool done = false;
    std::mutex mtx;
    std::condition_variable cv;
    
    std::thread worker([&]() {
        trantor::EventLoop loop;
        
        auto client = drogon::HttpClient::newHttpClient(
            (use_https ? "https://" : "http://") + url, 
            &loop
        );
        
        auto req = drogon::HttpRequest::newHttpRequest();
        req->setMethod(drogon::Get);
        req->setPath(path);
        
        client->sendRequest(req, [&](drogon::ReqResult res, const drogon::HttpResponsePtr &resp) {
            std::lock_guard<std::mutex> lock(mtx);
            if (res == drogon::ReqResult::Ok && resp) {
                result.status_code = resp->statusCode();
                result.body = resp->body();
                result.success = true;
            } else {
                result.status_code = 0;
                result.body = "";
                result.success = false;
            }
            done = true;
            cv.notify_one();
            loop.quit();
        }, timeout_seconds);
        
        loop.loop();
    });
    
    // Wait for completion
    {
        std::unique_lock<std::mutex> lock(mtx);
        cv.wait(lock, [&] { return done; });
    }
    
    worker.join();
    return result;
}